@@ -1,10 +1,9 @@
 """EIA Open Data API Client Package."""
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 
 from eia_client import api_key
-from eia_client.client import Client
+from eia_client import endpoint
 from eia_client import parse
-from eia_client.api_key import ApiKey
-from eia_client.endpoint import Endpoint, EndpointBuilder
+from eia_client.client import Client
